@@ -28,10 +28,8 @@ describe 'barbican::client' do
         'name'   => platform_params[:client_package_name],
         'tag'    => 'openstack'
       )}
-      it { is_expected.to contain_package('python-openstackclient').with(
-        'ensure' => 'present',
-        'tag'    => 'openstack',
-      )}
+
+      it { should contain_class('openstacklib::openstackclient') }
     end
 
     describe "with specified version" do
@@ -59,11 +57,7 @@ describe 'barbican::client' do
       let(:platform_params) do
         case facts[:osfamily]
         when 'Debian'
-          if facts[:os_package_type] == 'debian'
-            { :client_package_name => 'python3-barbicanclient' }
-          else
-            { :client_package_name => 'python-barbicanclient' }
-          end
+          { :client_package_name => 'python3-barbicanclient' }
         when 'RedHat'
           { :client_package_name => 'python-barbicanclient' }
         end
